aboutsummaryrefslogtreecommitdiffstats
path: root/coin_test_instructions.py
diff options
context:
space:
mode:
Diffstat (limited to 'coin_test_instructions.py')
-rw-r--r--coin_test_instructions.py9
1 files changed, 5 insertions, 4 deletions
diff --git a/coin_test_instructions.py b/coin_test_instructions.py
index d928b6857..5b08c773e 100644
--- a/coin_test_instructions.py
+++ b/coin_test_instructions.py
@@ -1,6 +1,6 @@
#############################################################################
##
-## Copyright (C) 2018 The Qt Company Ltd.
+## Copyright (C) 2019 The Qt Company Ltd.
## Contact: https://www.qt.io/licensing/
##
## This file is part of Qt for Python.
@@ -46,6 +46,7 @@ from build_scripts.utils import rmtree
from build_scripts.utils import acceptCITestConfiguration
from build_scripts.utils import get_ci_qmake_path
import os
+import sys
# Values must match COIN thrift
CI_HOST_OS = option_value("os")
@@ -68,7 +69,7 @@ def call_testrunner(python_ver, buildnro):
_pExe, _env, env_pip, env_python = get_qtci_virtualEnv(python_ver, CI_HOST_OS, CI_HOST_ARCH, CI_TARGET_ARCH)
rmtree(_env, True)
run_instruction(["virtualenv", "-p", _pExe, _env], "Failed to create virtualenv")
- install_pip_dependencies(env_pip, ["numpy", "PyOpenGL", "setuptools", "six"])
+ install_pip_dependencies(env_pip, ["numpy", "PyOpenGL", "setuptools", "six", "pyinstaller"])
install_pip_wheel_package(env_pip)
cmd = [env_python, "testrunner.py", "test",
"--blacklist", "build_history/blacklist.txt",
@@ -77,8 +78,8 @@ def call_testrunner(python_ver, buildnro):
qmake_path = get_ci_qmake_path(CI_ENV_INSTALL_DIR, CI_HOST_OS)
- # Try to install built wheels, and build some buildable examples.
- if CI_RELEASE_CONF:
+ # Try to install built wheels, and build some buildable examples (except macOS/Python 2.16)
+ if CI_RELEASE_CONF and CI_HOST_OS != 'MacOS' or sys.version_info[0] == 3:
wheel_tester_path = os.path.join("testing", "wheel_tester.py")
cmd = [env_python, wheel_tester_path, qmake_path]
run_instruction(cmd, "Error while running wheel_tester.py")